From 77a2acad8377dac03c7be3c5c4d7740ffb97ce22 Mon Sep 17 00:00:00 2001
From: Mark Dilger <mark.dilger@enterprisedb.com>
Date: Mon, 19 Oct 2020 17:08:34 -0700
Subject: [PATCH v1 1/2] Removing gratuitous inclusion of xlog_internal.h

Multiple files that were including xlog_internal.h did not need to
do so.
---
 src/backend/postmaster/bgwriter.c              | 1 -
 src/backend/replication/logical/decode.c       | 1 -
 src/backend/replication/logical/logical.c      | 1 -
 src/backend/replication/logical/logicalfuncs.c | 1 -
 src/backend/replication/logical/worker.c       | 1 -
 src/bin/pg_basebackup/pg_recvlogical.c         | 1 -
 src/bin/pg_rewind/timeline.c                   | 1 -
 src/bin/pg_waldump/rmgrdesc.c                  | 1 -
 8 files changed, 8 deletions(-)

diff --git a/src/backend/postmaster/bgwriter.c b/src/backend/postmaster/bgwriter.c
index a7afa758b6..aed72a75a9 100644
--- a/src/backend/postmaster/bgwriter.c
+++ b/src/backend/postmaster/bgwriter.c
@@ -35,7 +35,6 @@
 #include "postgres.h"
 
 #include "access/xlog.h"
-#include "access/xlog_internal.h"
 #include "libpq/pqsignal.h"
 #include "miscadmin.h"
 #include "pgstat.h"
diff --git a/src/backend/replication/logical/decode.c b/src/backend/replication/logical/decode.c
index 3f84ee99b8..19549862f2 100644
--- a/src/backend/replication/logical/decode.c
+++ b/src/backend/replication/logical/decode.c
@@ -30,7 +30,6 @@
 #include "access/heapam_xlog.h"
 #include "access/transam.h"
 #include "access/xact.h"
-#include "access/xlog_internal.h"
 #include "access/xlogreader.h"
 #include "access/xlogrecord.h"
 #include "access/xlogutils.h"
diff --git a/src/backend/replication/logical/logical.c b/src/backend/replication/logical/logical.c
index 8675832f4d..6471cb0d5e 100644
--- a/src/backend/replication/logical/logical.c
+++ b/src/backend/replication/logical/logical.c
@@ -29,7 +29,6 @@
 #include "postgres.h"
 
 #include "access/xact.h"
-#include "access/xlog_internal.h"
 #include "fmgr.h"
 #include "miscadmin.h"
 #include "pgstat.h"
diff --git a/src/backend/replication/logical/logicalfuncs.c b/src/backend/replication/logical/logicalfuncs.c
index b99c94e848..df2b110251 100644
--- a/src/backend/replication/logical/logicalfuncs.c
+++ b/src/backend/replication/logical/logicalfuncs.c
@@ -18,7 +18,6 @@
 #include <unistd.h>
 
 #include "access/xact.h"
-#include "access/xlog_internal.h"
 #include "access/xlogutils.h"
 #include "catalog/pg_type.h"
 #include "fmgr.h"
diff --git a/src/backend/replication/logical/worker.c b/src/backend/replication/logical/worker.c
index 3a5b733ee3..84578711c1 100644
--- a/src/backend/replication/logical/worker.c
+++ b/src/backend/replication/logical/worker.c
@@ -60,7 +60,6 @@
 #include "access/table.h"
 #include "access/tableam.h"
 #include "access/xact.h"
-#include "access/xlog_internal.h"
 #include "catalog/catalog.h"
 #include "catalog/namespace.h"
 #include "catalog/partition.h"
diff --git a/src/bin/pg_basebackup/pg_recvlogical.c b/src/bin/pg_basebackup/pg_recvlogical.c
index a4e0d6aeb2..3971bc7dd3 100644
--- a/src/bin/pg_basebackup/pg_recvlogical.c
+++ b/src/bin/pg_basebackup/pg_recvlogical.c
@@ -19,7 +19,6 @@
 #include <sys/select.h>
 #endif
 
-#include "access/xlog_internal.h"
 #include "common/fe_memutils.h"
 #include "common/file_perm.h"
 #include "common/logging.h"
diff --git a/src/bin/pg_rewind/timeline.c b/src/bin/pg_rewind/timeline.c
index 1ea6607189..5ba890a3c6 100644
--- a/src/bin/pg_rewind/timeline.c
+++ b/src/bin/pg_rewind/timeline.c
@@ -10,7 +10,6 @@
 #include "postgres_fe.h"
 
 #include "access/timeline.h"
-#include "access/xlog_internal.h"
 #include "pg_rewind.h"
 
 /*
diff --git a/src/bin/pg_waldump/rmgrdesc.c b/src/bin/pg_waldump/rmgrdesc.c
index 852d8ca4b1..5facf3da70 100644
--- a/src/bin/pg_waldump/rmgrdesc.c
+++ b/src/bin/pg_waldump/rmgrdesc.c
@@ -21,7 +21,6 @@
 #include "access/rmgr.h"
 #include "access/spgxlog.h"
 #include "access/xact.h"
-#include "access/xlog_internal.h"
 #include "catalog/storage_xlog.h"
 #include "commands/dbcommands_xlog.h"
 #include "commands/sequence.h"
-- 
2.21.1 (Apple Git-122.3)

